4.37. umbra.processing — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.37. umbra.processing

processing.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Processing` class.

Others:

## 4.37.1. Module Attributes

`umbra.processing.` `LOGGER`

`umbra.processing.` `UI_FILE`

## 4.37.2. Classes

class `umbra.processing.` `Processing`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  This class defines the Application processing status bar widget.

  Parameters: | parent – Object parent. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »